mb.eftest.report.pretty

A test reporter with an emphasis on pretty formatting.

A test reporter with an emphasis on pretty formatting.
raw docstring

*divider*clj

The divider to use between test failure and error reports.

The divider to use between test failure and error reports.
sourceraw docstring

*fonts*clj

The ANSI codes to use for reporting on tests.

The ANSI codes to use for reporting on tests.
sourceraw docstring

reportcljmultimethod

A reporting function compatible with clojure.test. Uses ANSI colors and terminal formatting to produce readable and 'pretty' reports.

A reporting function compatible with clojure.test. Uses ANSI colors and
terminal formatting to produce readable and 'pretty' reports.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries