Code related to running parallel tests, and utilities for disallowing dangerous stuff inside them.
Code related to running parallel tests, and utilities for disallowing dangerous stuff inside them.
Whether test currently being ran is being ran in parallel.
Whether test currently being ran is being ran in parallel.
(assert-test-is-not-parallel disallowed-message)Throw an exception if we are inside a ^:parallel test.
Throw an exception if we are inside a `^:parallel` test.
(parallel? test-var)Whether test-var can be ran in parallel with other parallel tests.
Metadata on the test takes precedence over metadata on its namespace. ^:synchronized is shorthand for
^{:parallel false} at either level.
Whether `test-var` can be ran in parallel with other parallel tests.
Metadata on the test takes precedence over metadata on its namespace. `^:synchronized` is shorthand for
`^{:parallel false}` at either level.cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |