A test reporter with an emphasis on pretty formatting.
A test reporter with an emphasis on pretty formatting.
The divider to use between test failure and error reports.
The divider to use between test failure and error reports.
The ANSI codes to use for reporting on tests.
The ANSI codes to use for reporting on tests.
A reporting function compatible with clojure.test. Uses ANSI colors and terminal formatting to produce readable and 'pretty' reports.
A reporting function compatible with clojure.test. Uses ANSI colors and terminal formatting to produce readable and 'pretty' reports.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |