Logic related to writing test results for a namespace to a JUnit XML file. See https://stackoverflow.com/a/9410271/1198455 for the JUnit output spec.
Logic related to writing test results for a namespace to a JUnit XML file. See https://stackoverflow.com/a/9410271/1198455 for the JUnit output spec.
(clean-output-dir!)Clear any files in the output dir; create it if needed.
Clear any files in the output dir; create it if needed.
(create-thread-pool!)Create a thread pool to write JUnit output with. JUnit output is written in background threads so tests are not slowed down by it.
Create a thread pool to write JUnit output with. JUnit output is written in background threads so tests are not slowed down by it.
(wait-for-writes-to-finish)Wait up to 10 seconds for the thread pool that writes results to finish.
Wait up to 10 seconds for the thread pool that writes results to finish.
(write-ns-result! result)Submit a background thread task to write the JUnit output for the tests in a namespace when an :end-test-ns event
is encountered.
Submit a background thread task to write the JUnit output for the tests in a namespace when an `:end-test-ns` event is encountered.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |